Receiver

Struct Receiver 

pub struct Receiver {
    pub org_id: String,
    pub secret: String,
    pub endpoint_url: String,
    pub address: String,
    pub client_id: String,
}
Information about a receipt receiver.

Contains the endpoint and authentication details needed to deliver receipts to a receiver. The receiver’s endpoint URL and secret are used to construct webhook deliveries.

Fields

org_id: String

Versa Org ID of the receiver

secret: String

Secret key for HMAC authentication

endpoint_url: String

Webhook endpoint URL

address: String

DEPRECATED: use endpoint_url instead

client_id: String

DEPRECATED: use org_id instead