pub struct HeaderThirdParty {
pub make_primary: bool,
pub merchant: Option<Org>,
pub relation: HeaderThirdPartyRelation,
}Expand description
HeaderThirdParty
JSON schema
{
"type": "object",
"required": [
"make_primary",
"relation"
],
"properties": {
"make_primary": {
"description": "Determines whether the merchant or third party gets top billing on the receipt",
"type": "boolean"
},
"merchant": {
"oneOf": [
{
"$ref": "#/$defs/org"
},
{
"type": "null"
}
]
},
"relation": {
"type": "string",
"enum": [
"bnpl",
"delivery_service",
"marketplace",
"payment_processor",
"platform",
"point_of_sale"
]
}
},
"additionalProperties": false
}Fields
make_primary: boolDetermines whether the merchant or third party gets top billing on the receipt
merchant: Option<Org>relation: HeaderThirdPartyRelationImplementations
Sourceimpl HeaderThirdParty
impl HeaderThirdParty
pub fn builder() -> HeaderThirdParty